import Component from '../component';
import Swiper from 'swiper';

export default class SwiperSlider extends Component {

	/**
	 * Инициализируем свайпер
	 * @param {object} props параметры свайпера
	 */
	constructor( props = {
		selector: '.swiper-container',
		options: {
			// Optional parameters
			// direction: 'vertical',
			loop: true,
		
			// If we need pagination
			pagination: {
			  el: '.swiper-pagination',
			},
		
			// Navigation arrows
			navigation: {
			  nextEl: '.swiper-button-next',
			  prevEl: '.swiper-button-prev',
			},
		
			// And if we need scrollbar
			scrollbar: {
			  el: '.swiper-scrollbar',
			},

			slidesPerView: 1
		}
	} ){
		super( props );

		this.state.swiper = new Swiper( this.props.selector, this.props.options );

		this.loadData( this.state );
	}

	/**
	 * загружаем данные
	 */
	loadData = () => {

		fetch( 'https://moscowseasons.com/graphql', {
			method: 'POST',
			headers: { 'Content-Type': 'application/json' },
			body: JSON.stringify({
				'operationName': 'albums',
				'variables': {
					'after': null,
					'before': null,
					'first': 4,
					'last': null,
					'locale': 'RU'
				},
				'query': 
					`query albums($locale: Locale, $after: String, $first: Int, $before: String, $last: Int) {
						albums(locale: $locale, after: $after, first: $first, before: $before, last: $last) {
							edges {
								node {
									id
									title
									photos {
										id
										url
										resized(width: 1200, height: 800) {
											url
											__typename
										}
										__typename
									}
									count
									__typename
								}
								__typename
							}
							pageInfo {
								hasNextPage
								startCursor
								endCursor
								__typename
							}
							__typename
						}
					}`
			})
		})
			.then( ( response ) => {
				return response.json();
			})
			.then( ( data ) => {

				data.data.albums.edges.forEach( ( album, index ) => {

					const slide = `<div class="swiper-item">
						<h3>Swiper ${index}</h3>
						<p>Swiper ${index} slide</p>
						<img src="${album.node.photos[0].resized.url}" alt="${album.node.title}" />
					</div>`;

					this.state.swiper.appendSlide( slide );
					
				});

				this.state.swiper.update();

				console.log(this.state.swiper)

			});
	}



}